RequestProvider class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchCities(int stateId) Future<List<Cities>>
Fetches the list of cities for a given state ID.
fetchCountries() Future<List<Country>>
Fetches the list of countries from the API.
fetchStates(int countryId) Future<List<States>>
Fetches the list of states for a given country ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance RequestProvider
no setter

Constants

baseUrl → const String