widget/awesome_location_picker library
Classes
- AwesomeLocationPicker
- AwesomeLocationPicker is a comprehensive Flutter widget that provides users with an intuitive interface to select their location by choosing a country, then a state within that country, and finally a city within the selected state.